package cn.com.infosec.asn1.esf;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DERSequence;

public class SignaturePolicyId extends ASN1Encodable {
   private DERObjectIdentifier sigPolicyId;
   private OtherHashAlgAndValue sigPolicyHash;
   private SigPolicyQualifiers sigPolicyQualifiers;

   public static SignaturePolicyId getInstance(Object obj) {
      if (obj != null && !(obj instanceof SignaturePolicyId)) {
         if (obj instanceof ASN1Sequence) {
            return new SignaturePolicyId((ASN1Sequence)obj);
         } else {
            throw new IllegalArgumentException("Unknown object in 'SignaturePolicyId' factory : " + obj.getClass().getName() + ".");
         }
      } else {
         return (SignaturePolicyId)obj;
      }
   }

   public SignaturePolicyId(ASN1Sequence seq) {
      if (seq.size() != 2 && seq.size() != 3) {
         throw new IllegalArgumentException("Bad sequence size: " + seq.size());
      } else {
         this.sigPolicyId = DERObjectIdentifier.getInstance(seq.getObjectAt(0));
         this.sigPolicyHash = OtherHashAlgAndValue.getInstance(seq.getObjectAt(1));
         if (seq.size() == 3) {
            this.sigPolicyQualifiers = SigPolicyQualifiers.getInstance(seq.getObjectAt(2));
         }

      }
   }

   public SignaturePolicyId(DERObjectIdentifier sigPolicyIdentifier, OtherHashAlgAndValue sigPolicyHash) {
      this(sigPolicyIdentifier, sigPolicyHash, (SigPolicyQualifiers)null);
   }

   public SignaturePolicyId(DERObjectIdentifier sigPolicyId, OtherHashAlgAndValue sigPolicyHash, SigPolicyQualifiers sigPolicyQualifiers) {
      this.sigPolicyId = sigPolicyId;
      this.sigPolicyHash = sigPolicyHash;
      this.sigPolicyQualifiers = sigPolicyQualifiers;
   }

   public DERObjectIdentifier getSigPolicyId() {
      return this.sigPolicyId;
   }

   public OtherHashAlgAndValue getSigPolicyHash() {
      return this.sigPolicyHash;
   }

   public SigPolicyQualifiers getSigPolicyQualifiers() {
      return this.sigPolicyQualifiers;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10001 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var1.add(this.sigPolicyId);
      var10001.add(this.sigPolicyHash);
      SigPolicyQualifiers var2;
      if ((var2 = this.sigPolicyQualifiers) != null) {
         var1.add(var2);
      }

      return new DERSequence(var1);
   }
}
